@@ -5,8 +5,8 @@
 # Author          : Johan Vromans
 # Created On      : Fri Jan 15 19:15:00 2016
 # Last Modified By: Johan Vromans
-# Last Modified On: Thu Oct  6 21:53:15 2016
-# Update Count    : 1402
+# Last Modified On: Mon Oct 10 15:02:43 2016
+# Update Count    : 1416
 # Status          : Unknown, Use with caution!
 
 ################ Common stuff ################
@@ -16,12 +16,13 @@ use warnings;
 use Carp;
 use utf8;
 use App::Packager;
+use FindBin;
 
 package Data::iRealPro::Output::Imager;
 
 use parent qw( Data::iRealPro::Output::Base );
 
-our $VERSION = "0.08";
+our $VERSION = "0.10";
 
 use Data::Dumper;
 use Text::CSV_XS;
@@ -61,7 +62,7 @@ sub new {
     }
 
     for ( qw( trace debug verbose output variant transpose toc crop
-	      npp npp_minor select
+	      npp npp_minor
 	   ) ) {
 	$self->{$_} = $options->{$_} if exists $options->{$_};
     }
@@ -116,6 +117,7 @@ my $fonts =
 # Colors.
 my $black = "#000000";
 my $red   = "#ff0000";
+my $blue  = "#0000ff";
 
 sub process {
     my ( $self, $u, $options ) = @_;
@@ -126,9 +128,7 @@ sub process {
     # If it is a playlist, assume multiple songs.
     # With --output this must be either a PDF, or
     # contain %d or %t.
-    if ( $plname && @{ $u->{playlist}->{songs} } > 1
-	 && !$options->{select}
-       ) {
+    if ( $plname && @{ $u->{playlist}->{songs} } > 1 ) {
 	if ( $self->{output}
 	     && $self->{output} !~ /\%\d*[dt]/
 	     && $self->{output} !~ /\.pdf$/i ) {
@@ -163,8 +163,7 @@ sub process {
     my $csv_fd;
     my $csv_name;
     if ( $outtype eq "pdf"
-	 && @{ $u->{playlist}->{songs} } > 1
-	 && !$options->{select} ) {
+	 && @{ $u->{playlist}->{songs} } > 1 ) {
 	$csv_name = $self->{output};
 	$csv_name =~ s/\.pdf$/.csv/i;
 	open( $csv_fd, ">:encoding(utf8)", $csv_name );
@@ -182,7 +181,6 @@ sub process {
     my @book;
     foreach my $song ( @{ $u->{playlist}->{songs} } ) {
 	$songix++;
-	next if $options->{select} && $songix != $options->{select};
 	warn( sprintf("Song %3d: %s\n", $songix, $song->{title}) )
 	  if $self->{verbose};
 	push( @book, [ $song->{title}, $pageno ] );
@@ -425,8 +423,8 @@ sub make_image {
 	}
 
 	# Adjust low water mark.
-	if ( $y + 40 > $low ) {
-	    $low = $y + 40;
+	if ( $y + $dy > $low ) {
+	    $low = $y + $dy;
 	}
 
 	#### Cell contents ################
@@ -649,6 +647,19 @@ sub make_image {
 	    next;
 	}
 
+	if ( $cell->flags && $cell->flags & 0x01 ) { # invisible END
+	    my $disp = 0;
+	    if ( $self->{npp} ) {
+		$self->textl( $x-2, $y + $dy - 27 - ($dy / 74) * $disp,
+			      "END", 60, $textfont, $blue );
+		next;
+	    }
+	    $self->textl( $x+0.15*$musicsize,
+			  $y+0.55*$musicsize-($disp/(45/$musicsize)),
+			  "END", 0.5*$musicsize, $textfont, $blue );
+	    next;
+	}
+
 	for ( $cell->mark ) {
 	    next unless $_;
 	    if ( $self->{npp} ) {
@@ -1078,7 +1089,7 @@ sub npp_chord {
 	    $x -= 31;
 	}
 	if ( $flags & CHORD_ALTERNATIVE ) {
-	    ...;
+	    # Need anything?
 	}
 	$self->{im}->rubthrough( src => $img,
 				 tx => $x, ty => $y );
